@@ -9,6 +9,7 @@ pub mod integration;
 pub mod member;
 pub mod role;
 pub mod sticker;
+pub mod update_current_member;
 pub mod update_guild;
 pub mod update_guild_channel_positions;
 pub mod user;
@@ -36,7 +37,10 @@ pub use self::{
     get_guild_preview::GetGuildPreview, get_guild_prune_count::GetGuildPruneCount,
     get_guild_vanity_url::GetGuildVanityUrl, get_guild_voice_regions::GetGuildVoiceRegions,
     get_guild_webhooks::GetGuildWebhooks, get_guild_welcome_screen::GetGuildWelcomeScreen,
-    get_guild_widget::GetGuildWidget, update_current_user_nick::UpdateCurrentUserNick,
+    get_guild_widget::GetGuildWidget, update_current_member::UpdateCurrentMember,
     update_guild::UpdateGuild, update_guild_channel_positions::UpdateGuildChannelPositions,
     update_guild_welcome_screen::UpdateGuildWelcomeScreen, update_guild_widget::UpdateGuildWidget,
 };
+
+#[deprecated(note = "use UpdateCurrentMember instead", since = "0.7.2")]
+pub type UpdateCurrentUserNick<'a> = self::update_current_user_nick::UpdateCurrentUserNick<'a>;
