@@ -99,6 +99,8 @@ struct UpdateGuildFields<'a> {
     public_updates_channel_id: Option<NullableField<ChannelId>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     preferred_locale: Option<NullableField<&'a str>>,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    premium_progress_bar_enabled: Option<bool>,
 }
 
 /// Update a guild.
@@ -135,6 +137,7 @@ impl<'a> UpdateGuild<'a> {
                 rules_channel_id: None,
                 public_updates_channel_id: None,
                 preferred_locale: None,
+                premium_progress_bar_enabled: None,
             },
             guild_id,
             http,
@@ -321,6 +324,16 @@ impl<'a> UpdateGuild<'a> {
         self
     }
 
+    /// Set whether the premium progress bar is enabled.
+    pub const fn premium_progress_bar_enabled(
+        mut self,
+        premium_progress_bar_enabled: bool,
+    ) -> Self {
+        self.fields.premium_progress_bar_enabled = Some(premium_progress_bar_enabled);
+
+        self
+    }
+
     /// Execute the request, returning a future resolving to a [`Response`].
     ///
     /// [`Response`]: crate::response::Response
