@@ -4,12 +4,14 @@ pub mod update_current_user;
 mod create_private_channel;
 mod get_current_user;
 mod get_current_user_connections;
+mod get_current_user_guild_member;
 mod get_user;
 mod leave_guild;
 
 pub use self::{
     create_private_channel::CreatePrivateChannel, get_current_user::GetCurrentUser,
     get_current_user_connections::GetCurrentUserConnections,
+    get_current_user_guild_member::GetCurrentUserGuildMember,
     get_current_user_guilds::GetCurrentUserGuilds, get_user::GetUser, leave_guild::LeaveGuild,
     update_current_user::UpdateCurrentUser,
 };
