@@ -7,10 +7,12 @@ use super::{application::InteractionError, guild::sticker::StickerValidationErro
 use std::{
     error::Error,
     fmt::{Display, Formatter, Result as FmtResult},
+    time::{SystemTime, UNIX_EPOCH},
 };
 use twilight_model::{
     application::component::{select_menu::SelectMenuOption, Component, ComponentType},
-    channel::{embed::Embed, ChannelType},
+    channel::{embed::Embed, message::sticker::StickerId, ChannelType},
+    datetime::Timestamp,
 };
 
 /// A provided [`Component`] is invalid.
@@ -1175,6 +1177,33 @@ fn _sticker_tags(value: &str) -> bool {
         .contains(&len)
 }
 
+pub fn sticker_limit(value: &[StickerId]) -> bool {
+    let len = value.len();
+
+    // https://discord.com/developers/docs/resources/channel#create-message-jsonform-params
+    (0..=3).contains(&len)
+}
+
+pub fn communication_disabled_until(timestamp: Timestamp) -> bool {
+    _communication_disabled_until(timestamp)
+}
+
+const COMMUNICATION_DISABLED_MAX_DURATION: i64 = 28 * 24 * 60 * 60;
+
+#[allow(clippy::cast_possible_wrap)] // casting of unix timestamp should never wrap
+fn _communication_disabled_until(timestamp: Timestamp) -> bool {
+    let now = SystemTime::now().duration_since(UNIX_EPOCH);
+
+    match now {
+        Ok(now) => {
+            let end = timestamp.as_secs();
+
+            end - now.as_secs() as i64 <= COMMUNICATION_DISABLED_MAX_DURATION
+        }
+        Err(_) => false,
+    }
+}
+
 /// Validate the number of guild command permission overwrites.
 ///
 /// The maximum number of commands allowed in a guild is defined by
