@@ -604,7 +604,7 @@ impl Display for RouteDisplay<'_> {
                 f.write_str("/followers")
             }
             Route::GetActiveThreads { guild_id } => {
-                f.write_str("guild_id/")?;
+                f.write_str("guilds/")?;
                 Display::fmt(guild_id, f)?;
 
                 f.write_str("/threads/active")
@@ -668,8 +668,14 @@ impl Display for RouteDisplay<'_> {
 
                 f.write_str("/permissions")
             }
-            Route::GetCurrentUserApplicationInfo => f.write_str("/oauth2/applications/@me"),
+            Route::GetCurrentUserApplicationInfo => f.write_str("oauth2/applications/@me"),
             Route::GetCurrentUser | Route::UpdateCurrentUser => f.write_str("users/@me"),
+            Route::GetCurrentUserGuildMember { guild_id } => {
+                f.write_str("users/@me/guilds/")?;
+                Display::fmt(guild_id, f)?;
+
+                f.write_str("/member")
+            }
             Route::GetGateway => f.write_str("gateway"),
             Route::GetGuild {
                 guild_id,
@@ -2347,7 +2353,7 @@ mod tests {
         let route = Route::GetActiveThreads { guild_id: GUILD_ID };
         assert_eq!(
             route.display().to_string(),
-            format!("guild_id/{guild_id}/threads/active", guild_id = GUILD_ID)
+            format!("guilds/{guild_id}/threads/active", guild_id = GUILD_ID)
         );
     }
 
@@ -2405,7 +2411,7 @@ mod tests {
     #[test]
     fn test_get_current_user_application_info() {
         let route = Route::GetCurrentUserApplicationInfo;
-        assert_eq!(route.display().to_string(), "/oauth2/applications/@me");
+        assert_eq!(route.display().to_string(), "oauth2/applications/@me");
     }
 
     #[test]
@@ -2414,6 +2420,15 @@ mod tests {
         assert_eq!(route.display().to_string(), "users/@me");
     }
 
+    #[test]
+    fn test_get_current_user_guild_member() {
+        let route = Route::GetCurrentUserGuildMember { guild_id: GUILD_ID };
+        assert_eq!(
+            route.display().to_string(),
+            format!("users/@me/guilds/{guild_id}/member", guild_id = GUILD_ID)
+        )
+    }
+
     #[test]
     fn test_update_current_user() {
         let route = Route::UpdateCurrentUser;
